@@ -7,8 +7,9 @@
 """
 
 import tkinter as tk
+from tkinter import ttk
 
-from .button import Button3d
+from .button import Button3d, Radiobutton, Checkbutton
 from .frame import Frame3d, ScrollableFrame
 from .menu import RightClickMenu
 from .progressbar import RadialProgressbar, RadialProgressbar3d
@@ -16,11 +17,13 @@ from .scrollbar import SimpleScrollbar
 from .text import ScrolledText
 from .utils import *
 from .config import *
+from .version import __version__
 
 
 def main():
     
     root = tk.Tk()
+    root.title('AwesomeTkinter ' + __version__)
     root.config(background=DEFAULT_COLOR)
 
     # select tkinter theme required for things to be right on windows,
@@ -31,7 +34,7 @@ def main():
     f1 = Frame3d(root)
     f1.pack(side='left', expand=True, fill='both', padx=3, pady=3)
 
-    bar = RadialProgressbar3d(f1, fg='cyan', size=120)
+    bar = RadialProgressbar3d(f1, fg='cyan', size=120, font_size_ratio=0.08)
     bar.pack(padx=20, pady=20)
     bar.start()
 
